--
-- Copyright (C) 2012-2015 Snail <https://github.com/snail23/snailui/>
--
-- This program is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by the
-- Free Software Foundation; either version 2 of the License, or (at your
-- option) any later version.
--
-- This program is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-- FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
-- more details.
--
-- You should have received a copy of the GNU General Public License along
-- with this program. If not, see <http://www.gnu.org/licenses/>.
--

function HandleBattlegroundScore()
	OnBattlegroundScoreEvent = function(Self, Event)
		if GetConfiguration().BattlegroundScore and ExtraButton.Shown then
			if InActiveBattlefield() or (GetNumWorldStateUI() > 1) then
				Self:Show()

				local PointsPattern = "(%d+)"
				local PointsAndMaxPointsPattern = "(%d+)/(%d+)"
				local PointsAndMaxPointsAndBasesPattern = "([a-zA-Z: ]+)(%d+)([a-zA-Z: ]+)(%d+)/(%d+)"

				local function GetBattlegroundInfo(Text)
					local Bases
					local Points
					local MaxPoints
					local Zone = GetZoneText()

					if (Zone == "Alterac Valley") or (Zone == "Isle of Conquest") then
						_, _, Points = string.find(Text, PointsPattern)
						MaxPoints = (Zone == "Isle of Conquest") and "300" or "500"
					elseif (Zone == "Arathi Basin") or (Zone == "Deepwind Gorge") or (Zone == "Eye of the Storm") or (Zone == "The Battle for Gilneas") then
						_, _, _, Bases, _, Points, MaxPoints = string.find(Text, PointsAndMaxPointsAndBasesPattern)
					elseif (Zone == "Silvershard Mines") or (Zone == "Temple of Kotmogu") or (Zone == "Twin Peaks") or (Zone == "Wintergrasp") or (Zone == "Warsong Gulch") then
						_, _, Points, MaxPoints = string.find(Text, PointsAndMaxPointsPattern)
					end

					return Bases, Points, MaxPoints
				end

				for I = 1, GetNumWorldStateUI() do
					if I == ((GetZoneText() == "Eye of the Storm") and (Self.Index + 1) or Self.Index) then
						local _, State, _, Text = GetWorldStateUIInfo(I)

						if State == 2 then
							Self.Icon:Show()
						else
							Self.Icon:Hide()
						end

						local Bases, Points, MaxPoints = GetBattlegroundInfo(Text)

						if Points and (strlen(Points) > 0) then
							if Points == "0" then
								Points = "0.00001"
							end

							Self.Bar:SetSize((GetConfiguration().BattlegroundScore.Width - 6) * (tonumber(Points) / tonumber(MaxPoints)), GetConfiguration().BattlegroundScore.Height - 6)
							Self.Bar.Text:SetText(((Bases and (strlen(Bases) > 0)) and Bases .. ": " or "") .. math.floor(tonumber(Points)) .. "/" .. MaxPoints)
						else
							Self.Bar:SetSize(GetConfiguration().BattlegroundScore.Width - 6, GetConfiguration().BattlegroundScore.Height - 6)
							Self.Bar.Text:SetText(Text)
						end
					end
				end
			else
				Self:Hide()
			end
		end
	end

	if GetConfiguration().BattlegroundScore then
		AllianceBattlegroundScore = CreateFrame("Frame", nil, UIParent)
		AllianceBattlegroundScore:RegisterEvent("PLAYER_ENTERING_BATTLEGROUND")
		AllianceBattlegroundScore:RegisterEvent("PLAYER_ENTERING_WORLD")
		AllianceBattlegroundScore:RegisterEvent("UPDATE_WORLD_STATES")
		AllianceBattlegroundScore:SetPoint(GetConfiguration().BattlegroundScore.Anchor, GetConfiguration().BattlegroundScore.X, GetConfiguration().BattlegroundScore.Y)
		AllianceBattlegroundScore:SetScript("OnEvent", OnBattlegroundScoreEvent)
		AllianceBattlegroundScore:SetSize(GetConfiguration().BattlegroundScore.Width - 4, GetConfiguration().BattlegroundScore.Height - 4)

		AllianceBattlegroundScore.Background = AllianceBattlegroundScore:CreateTexture(nil, "LOW")
		AllianceBattlegroundScore.Background:SetPoint("TOPLEFT", -1, 1)
		AllianceBattlegroundScore.Background:SetSize(GetConfiguration().BattlegroundScore.Width - 2, GetConfiguration().BattlegroundScore.Height - 2)
		AllianceBattlegroundScore.Background:SetTexture(PLAYER_FACTION_COLORS[1].r, PLAYER_FACTION_COLORS[1].g, PLAYER_FACTION_COLORS[1].b)

		AllianceBattlegroundScore.Border = AllianceBattlegroundScore:CreateTexture(nil, "BACKGROUND")
		AllianceBattlegroundScore.Border:SetPoint("TOPLEFT", -2, 2)
		AllianceBattlegroundScore.Border:SetSize(GetConfiguration().BattlegroundScore.Width, GetConfiguration().BattlegroundScore.Height)
		AllianceBattlegroundScore.Border:SetTexture(0, 0, 0)

		AllianceBattlegroundScore.Bar = CreateFrame("StatusBar", nil, AllianceBattlegroundScore)
		AllianceBattlegroundScore.Bar:SetPoint("TOPLEFT", 1, -1)
		AllianceBattlegroundScore.Bar:SetSize(GetConfiguration().BattlegroundScore.Width - 6, GetConfiguration().BattlegroundScore.Height - 6)
		AllianceBattlegroundScore.Bar:SetStatusBarTexture(Configuration.Texture)
		AllianceBattlegroundScore.Bar:SetStatusBarColor(PLAYER_FACTION_COLORS[1].r, PLAYER_FACTION_COLORS[1].g, PLAYER_FACTION_COLORS[1].b)

		AllianceBattlegroundScore.Bar.Border = AllianceBattlegroundScore.Bar:CreateTexture(nil, "BACKGROUND")
		AllianceBattlegroundScore.Bar.Border:SetPoint("TOPLEFT", -1, 1)
		AllianceBattlegroundScore.Bar.Border:SetSize(GetConfiguration().BattlegroundScore.Width - 4, GetConfiguration().BattlegroundScore.Height - 4)
		AllianceBattlegroundScore.Bar.Border:SetTexture(0, 0, 0)

		AllianceBattlegroundScore.Bar.Text = AllianceBattlegroundScore.Bar:CreateFontString(nil, "OVERLAY")
		AllianceBattlegroundScore.Bar.Text:SetFont(Configuration.Font.Name, Configuration.Font.Size, Configuration.Font.Outline)
		AllianceBattlegroundScore.Bar.Text:SetPoint("CENTER", AllianceBattlegroundScore, 1, 0)
		AllianceBattlegroundScore.Bar.Text:SetTextColor(PLAYER_FACTION_COLORS[1].r * Configuration.TextColorPercentage, PLAYER_FACTION_COLORS[1].g * Configuration.TextColorPercentage, PLAYER_FACTION_COLORS[1].b * Configuration.TextColorPercentage)

		AllianceBattlegroundScore.Icon = CreateFrame("Frame", nil, AllianceBattlegroundScore)

		AllianceBattlegroundScore.Icon.Icon = AllianceBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		AllianceBattlegroundScore.Icon.Icon:SetPoint("LEFT", AllianceBattlegroundScore, -(GetConfiguration().BattlegroundScore.Height * 2) - 3, 0)
		AllianceBattlegroundScore.Icon.Icon:SetSize((GetConfiguration().BattlegroundScore.Height * 2) - 6, GetConfiguration().BattlegroundScore.Height - 6)
		AllianceBattlegroundScore.Icon.Icon:SetTexCoord(GetConfiguration().BattlegroundScore.TextureCoordinate.Left, GetConfiguration().BattlegroundScore.TextureCoordinate.Right, GetConfiguration().BattlegroundScore.TextureCoordinate.Top, GetConfiguration().BattlegroundScore.TextureCoordinate.Bottom)
		AllianceBattlegroundScore.Icon.Icon:SetTexture("Interface/ICONS/PVPCurrency-Honor-Horde.png")

		AllianceBattlegroundScore.Icon.IconBackgroundBottom = AllianceBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		AllianceBattlegroundScore.Icon.IconBackgroundBottom:SetPoint("BOTTOM", AllianceBattlegroundScore.Icon.Icon, 0, -2)
		AllianceBattlegroundScore.Icon.IconBackgroundBottom:SetSize((GetConfiguration().BattlegroundScore.Height * 2) - 2, 1)
		AllianceBattlegroundScore.Icon.IconBackgroundBottom:SetTexture(PLAYER_FACTION_COLORS[1].r, PLAYER_FACTION_COLORS[1].g, PLAYER_FACTION_COLORS[1].b)

		AllianceBattlegroundScore.Icon.IconBackgroundLeft = AllianceBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		AllianceBattlegroundScore.Icon.IconBackgroundLeft:SetPoint("LEFT", AllianceBattlegroundScore.Icon.Icon, -2, 0)
		AllianceBattlegroundScore.Icon.IconBackgroundLeft:SetSize(1, GetConfiguration().BattlegroundScore.Height - 4)
		AllianceBattlegroundScore.Icon.IconBackgroundLeft:SetTexture(PLAYER_FACTION_COLORS[1].r, PLAYER_FACTION_COLORS[1].g, PLAYER_FACTION_COLORS[1].b)

		AllianceBattlegroundScore.Icon.IconBackgroundRight = AllianceBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		AllianceBattlegroundScore.Icon.IconBackgroundRight:SetPoint("RIGHT", AllianceBattlegroundScore.Icon.Icon, 2, 0)
		AllianceBattlegroundScore.Icon.IconBackgroundRight:SetSize(1, GetConfiguration().BattlegroundScore.Height - 4)
		AllianceBattlegroundScore.Icon.IconBackgroundRight:SetTexture(PLAYER_FACTION_COLORS[1].r, PLAYER_FACTION_COLORS[1].g, PLAYER_FACTION_COLORS[1].b)

		AllianceBattlegroundScore.Icon.IconBackgroundTop = AllianceBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		AllianceBattlegroundScore.Icon.IconBackgroundTop:SetPoint("TOP", AllianceBattlegroundScore.Icon.Icon, 0, 2)
		AllianceBattlegroundScore.Icon.IconBackgroundTop:SetSize((GetConfiguration().BattlegroundScore.Height * 2) - 2, 1)
		AllianceBattlegroundScore.Icon.IconBackgroundTop:SetTexture(PLAYER_FACTION_COLORS[1].r, PLAYER_FACTION_COLORS[1].g, PLAYER_FACTION_COLORS[1].b)

		AllianceBattlegroundScore.Icon.IconBorder = AllianceBattlegroundScore.Icon:CreateTexture(nil, "BACKGROUND")
		AllianceBattlegroundScore.Icon.IconBorder:SetPoint("TOPLEFT", AllianceBattlegroundScore.Icon.Icon, -3, 3)
		AllianceBattlegroundScore.Icon.IconBorder:SetSize(GetConfiguration().BattlegroundScore.Height * 2, GetConfiguration().BattlegroundScore.Height)
		AllianceBattlegroundScore.Icon.IconBorder:SetTexture(0, 0, 0)

		AllianceBattlegroundScore.Index = 2

		if GetConfiguration().ExtraButton then
			AllianceBattlegroundScore:Hide()
		end

		HordeBattlegroundScore = CreateFrame("Frame", nil, UIParent)
		HordeBattlegroundScore:RegisterEvent("PLAYER_ENTERING_BATTLEGROUND")
		HordeBattlegroundScore:RegisterEvent("PLAYER_ENTERING_WORLD")
		HordeBattlegroundScore:RegisterEvent("UPDATE_WORLD_STATES")
		HordeBattlegroundScore:SetPoint(GetConfiguration().BattlegroundScore.Anchor, GetConfiguration().BattlegroundScore.X, (GetConfiguration().BattlegroundScore.Y - GetConfiguration().BattlegroundScore.Height) - 4)
		HordeBattlegroundScore:SetScript("OnEvent", OnBattlegroundScoreEvent)
		HordeBattlegroundScore:SetSize(GetConfiguration().BattlegroundScore.Width - 4, GetConfiguration().BattlegroundScore.Height - 4)

		HordeBattlegroundScore.Background = HordeBattlegroundScore:CreateTexture(nil, "LOW")
		HordeBattlegroundScore.Background:SetPoint("TOPLEFT", -1, 1)
		HordeBattlegroundScore.Background:SetSize(GetConfiguration().BattlegroundScore.Width - 2, GetConfiguration().BattlegroundScore.Height - 2)
		HordeBattlegroundScore.Background:SetTexture(PLAYER_FACTION_COLORS[0].r, PLAYER_FACTION_COLORS[0].g, PLAYER_FACTION_COLORS[0].b)

		HordeBattlegroundScore.Border = HordeBattlegroundScore:CreateTexture(nil, "BACKGROUND")
		HordeBattlegroundScore.Border:SetPoint("TOPLEFT", -2, 2)
		HordeBattlegroundScore.Border:SetSize(GetConfiguration().BattlegroundScore.Width, GetConfiguration().BattlegroundScore.Height)
		HordeBattlegroundScore.Border:SetTexture(0, 0, 0)

		HordeBattlegroundScore.Bar = CreateFrame("StatusBar", nil, HordeBattlegroundScore)
		HordeBattlegroundScore.Bar:SetPoint("TOPLEFT", 1, -1)
		HordeBattlegroundScore.Bar:SetSize(GetConfiguration().BattlegroundScore.Width - 6, GetConfiguration().BattlegroundScore.Height - 6)
		HordeBattlegroundScore.Bar:SetStatusBarTexture(Configuration.Texture)
		HordeBattlegroundScore.Bar:SetStatusBarColor(PLAYER_FACTION_COLORS[0].r, PLAYER_FACTION_COLORS[0].g, PLAYER_FACTION_COLORS[0].b)

		HordeBattlegroundScore.Bar.Border = HordeBattlegroundScore.Bar:CreateTexture(nil, "BACKGROUND")
		HordeBattlegroundScore.Bar.Border:SetPoint("TOPLEFT", -1, 1)
		HordeBattlegroundScore.Bar.Border:SetSize(GetConfiguration().BattlegroundScore.Width - 4, GetConfiguration().BattlegroundScore.Height - 4)
		HordeBattlegroundScore.Bar.Border:SetTexture(0, 0, 0)

		HordeBattlegroundScore.Bar.Text = HordeBattlegroundScore.Bar:CreateFontString(nil, "OVERLAY")
		HordeBattlegroundScore.Bar.Text:SetFont(Configuration.Font.Name, Configuration.Font.Size, Configuration.Font.Outline)
		HordeBattlegroundScore.Bar.Text:SetPoint("CENTER", HordeBattlegroundScore, 1, 0)
		HordeBattlegroundScore.Bar.Text:SetTextColor(PLAYER_FACTION_COLORS[0].r * Configuration.TextColorPercentage, PLAYER_FACTION_COLORS[0].g * Configuration.TextColorPercentage, PLAYER_FACTION_COLORS[0].b * Configuration.TextColorPercentage)

		HordeBattlegroundScore.Icon = CreateFrame("Frame", nil, HordeBattlegroundScore)

		HordeBattlegroundScore.Icon.Icon = HordeBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		HordeBattlegroundScore.Icon.Icon:SetPoint("LEFT", HordeBattlegroundScore, -(GetConfiguration().BattlegroundScore.Height * 2) - 3, 0)
		HordeBattlegroundScore.Icon.Icon:SetSize((GetConfiguration().BattlegroundScore.Height * 2) - 6, GetConfiguration().BattlegroundScore.Height - 6)
		HordeBattlegroundScore.Icon.Icon:SetTexCoord(GetConfiguration().BattlegroundScore.TextureCoordinate.Left, GetConfiguration().BattlegroundScore.TextureCoordinate.Right, GetConfiguration().BattlegroundScore.TextureCoordinate.Top, GetConfiguration().BattlegroundScore.TextureCoordinate.Bottom)
		HordeBattlegroundScore.Icon.Icon:SetTexture("Interface/ICONS/PVPCurrency-Honor-Alliance.png")

		HordeBattlegroundScore.Icon.IconBackgroundBottom = HordeBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		HordeBattlegroundScore.Icon.IconBackgroundBottom:SetPoint("BOTTOM", HordeBattlegroundScore.Icon.Icon, 0, -2)
		HordeBattlegroundScore.Icon.IconBackgroundBottom:SetSize((GetConfiguration().BattlegroundScore.Height * 2) - 2, 1)
		HordeBattlegroundScore.Icon.IconBackgroundBottom:SetTexture(PLAYER_FACTION_COLORS[0].r, PLAYER_FACTION_COLORS[0].g, PLAYER_FACTION_COLORS[0].b)

		HordeBattlegroundScore.Icon.IconBackgroundLeft = HordeBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		HordeBattlegroundScore.Icon.IconBackgroundLeft:SetPoint("LEFT", HordeBattlegroundScore.Icon.Icon, -2, 0)
		HordeBattlegroundScore.Icon.IconBackgroundLeft:SetSize(1, GetConfiguration().BattlegroundScore.Height - 4)
		HordeBattlegroundScore.Icon.IconBackgroundLeft:SetTexture(PLAYER_FACTION_COLORS[0].r, PLAYER_FACTION_COLORS[0].g, PLAYER_FACTION_COLORS[0].b)

		HordeBattlegroundScore.Icon.IconBackgroundRight = HordeBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		HordeBattlegroundScore.Icon.IconBackgroundRight:SetPoint("RIGHT", HordeBattlegroundScore.Icon.Icon, 2, 0)
		HordeBattlegroundScore.Icon.IconBackgroundRight:SetSize(1, GetConfiguration().BattlegroundScore.Height - 4)
		HordeBattlegroundScore.Icon.IconBackgroundRight:SetTexture(PLAYER_FACTION_COLORS[0].r, PLAYER_FACTION_COLORS[0].g, PLAYER_FACTION_COLORS[0].b)

		HordeBattlegroundScore.Icon.IconBackgroundTop = HordeBattlegroundScore.Icon:CreateTexture(nil, "LOW")
		HordeBattlegroundScore.Icon.IconBackgroundTop:SetPoint("TOP", HordeBattlegroundScore.Icon.Icon, 0, 2)
		HordeBattlegroundScore.Icon.IconBackgroundTop:SetSize((GetConfiguration().BattlegroundScore.Height * 2) - 2, 1)
		HordeBattlegroundScore.Icon.IconBackgroundTop:SetTexture(PLAYER_FACTION_COLORS[0].r, PLAYER_FACTION_COLORS[0].g, PLAYER_FACTION_COLORS[0].b)

		HordeBattlegroundScore.Icon.IconBorder = HordeBattlegroundScore.Icon:CreateTexture(nil, "BACKGROUND")
		HordeBattlegroundScore.Icon.IconBorder:SetPoint("TOPLEFT", HordeBattlegroundScore.Icon.Icon, -3, 3)
		HordeBattlegroundScore.Icon.IconBorder:SetSize(GetConfiguration().BattlegroundScore.Height * 2, GetConfiguration().BattlegroundScore.Height)
		HordeBattlegroundScore.Icon.IconBorder:SetTexture(0, 0, 0)

		HordeBattlegroundScore.Index = 3

		if GetConfiguration().ExtraButton then
			HordeBattlegroundScore:Hide()
		end
	end
end
